@@ -127,7 +127,7 @@ class Win32File(OSFile):
     def ioctl(self, control_code, input, input_size, output=None, output_size=0):
         bytes_returned = c_ulong(0)
         if not DeviceIoControl(self.handle, control_code, input, input_size, output or 0, output_size,
-                               byref(bytes_returned), 0):
+                               byref(bytes_returned), None):
             raise AsiWin32OSError(GetLastError(), "DeviceIoControl %d for path %s failed" % (control_code, self.path))
         return bytes_returned.value
 
@@ -381,4 +381,4 @@ class Win32CommandExecuter(CommandExecuterBase):
         yield (data, spt.packet_id)
 
 # backward compatibility
-OSFile = Win32File
\ No newline at end of file
+OSFile = Win32File
